@@ -1,46 +1,35 @@
 package Pod::Weaver::Section::Source::DefaultGitHub;
 
+our $DATE = '2015-04-01'; # DATE
+our $VERSION = '0.06'; # VERSION
+
 use 5.010001;
 use Moose;
 #use Text::Wrap ();
+with 'Pod::Weaver::Role::AddTextToSection';
 with 'Pod::Weaver::Role::Section';
 
-#use Log::Any '$log';
-
-use Moose::Autobox;
-
-our $VERSION = '0.05'; # VERSION
-
 sub weave_section {
-  my ($self, $document, $input) = @_;
+    my ($self, $document, $input) = @_;
 
-  my $repo_url = $input->{distmeta}{resources}{repository};
-  if (ref($repo_url) eq 'HASH') { $repo_url = $repo_url->{web} }
-  if (!$repo_url) {
-      my $file = ".git/config";
-      die "Can't find git config file $file" unless -f $file;
-      my $ct = do {
-          local $/;
-          open my($fh), "<", $file or die "Can't open $file: $!";
-          ~~<$fh>;
-      };
-      $ct =~ m!github\.com:([^/]+)/(.+)\.git!
-          or die "Can't parse github address in $file";
-      $repo_url = "https://github.com/$1/$2";
-  }
-  my $text = "Source repository is at L<$repo_url>.";
+    my $repo_url = $input->{distmeta}{resources}{repository};
+    if (ref($repo_url) eq 'HASH') { $repo_url = $repo_url->{web} }
+    if (!$repo_url) {
+        my $file = ".git/config";
+        die "Can't find git config file $file" unless -f $file;
+        my $ct = do {
+            local $/;
+            open my($fh), "<", $file or die "Can't open $file: $!";
+            ~~<$fh>;
+        };
+        $ct =~ m!github\.com:([^/]+)/(.+)\.git!
+            or die "Can't parse github address in $file";
+        $repo_url = "https://github.com/$1/$2";
+    }
+    my $text = "Source repository is at L<$repo_url>.";
 
-  #$text = Text::Wrap::wrap(q{}, q{}, $text);
-
-  $document->children->push(
-    Pod::Elemental::Element::Nested->new({
-      command  => 'head1',
-      content  => 'SOURCE',
-      children => [
-        Pod::Elemental::Element::Pod5::Ordinary->new({ content => $text }),
-      ],
-    }),
-  );
+    #$text = Text::Wrap::wrap(q{}, q{}, $text);
+    $self->add_text_to_section($document, $text, 'SOURCE');
 }
 
 no Moose;
@@ -59,7 +48,7 @@ Pod::Weaver::Section::Source::DefaultGitHub - Add a SOURCE section (repository d
 
 =head1 VERSION
 
-This document describes version 0.05 of Pod::Weaver::Section::Source::DefaultGitHub (from Perl distribution Pod-Weaver-Section-Source-DefaultGitHub), released on 2015-01-07.
+This document describes version 0.06 of Pod::Weaver::Section::Source::DefaultGitHub (from Perl distribution Pod-Weaver-Section-Source-DefaultGitHub), released on 2015-04-01.
 
 =head1 SYNOPSIS
 
@@ -89,9 +78,7 @@ L<Pod::Weaver::Section::SourceGitHub>
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Section-Source-DefaultGitHub>.
-
-=head1 SOURCE
+Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Section-Source-DefaultGitHub>.=head1 SOURCE
 
 Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Section-Source-DefaultGitHub>.
 
@@ -102,7 +89,6 @@ Please report any bugs or feature requests on the bugtracker website L<https://r
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
